@@ -10,6 +10,7 @@
 #include <cmath>
 #include <assert.h>
 #include <set>
+#include <cstring>
 
 namespace geodesic{
 
@@ -680,7 +681,7 @@ inline void GeodesicAlgorithmExact::propagate(std::vector<SurfacePoint>& sources
 
 inline bool GeodesicAlgorithmExact::check_stop_conditions(unsigned& index)
 {
-    double queue_distance = (*m_queue.begin())->min();
+    double queue_distance = m_queue.empty() ? GEODESIC_INF : (*m_queue.begin())->min();
     if(queue_distance < stop_distance())
     {
         return false;
